%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Institution: Stanford University
% Project: RealSimple Psychoacoustics Lab
% Author: Ryan J. Cassidy
% Date: Fall 2006
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% EXCITPATPLOT Plots the input excitogram.
%
% excitPatPlot(xExcitogram, BandCentersHz)
%
%    - xExcitogram is the excitogram produced by fftInt2ExcitPat(), and
%    - BandCentersHz are the frequencies at which the xExcitogram is computed.
%
% [1] B. R. Glasberg and B. C. J. Moore, "A model of loudness applicable to
% time-varying sounds", Journal of the Audio Engineering Society,
% 50(5):331--342, 2002.
% 
% VERSION CONTROL INFORMATION:
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function excitPatPlot(xExcitogram, bandCentersHz)

% Plot excitogram.
fig_num_base = 10;
figure(fig_num_base+0);clf;
hopTimeMS = 1; % time between frames, in milliseconds
[egArrayLen,nFrames] = size(xExcitogram);
centerTimeMS = (0:nFrames-1)*hopTimeMS;
excitPatDB = 10*log10(xExcitogram);
printplots = 0;      % 1 to print, 0 to skip
domesh = 0; % mesh is too large for printing
dbdown = 80;         % clip displays this many dB below 0 dB
colormap('gray'); map = colormap; imap = flipud(map);
bandCentersERB = freq2erb(bandCentersHz);

mymeshplot(centerTimeMS,bandCentersERB,excitPatDB,dbdown,domesh);
hold on;
%plot(linetimes,lineheights,'--k');
title('Cochlear Excitogram');
xlabel('Time (ms)');ylabel('ERB Number');zlabel('Intensity (dB)');
%view(127.5,30);zoom on; % from an angle
view(0,90);zoom on; % from top
colormap(imap);
if printplots, 
  cmd = sprintf('print -deps %s/lsg-ep.eps',pdir); 
  disp(cmd); eval(cmd);
end
hold off;
grid on;
	       

