% FREQ2ERB frequency conversion from Hz to ERB units
% [FREQ_VECTOR_ERB] = FREQ2ERB(FREQ_VECTOR_HZ)
%   freq_vector_hz is a vector of frequency values in Hz
%   freq_vector_erb is a vector of corresponding frequency values in ERBs
%     (equivalent rectangular bandwidths) 
%
% Taken from equation (4) on p. 114 of: 
%     Brian R. Glasberg and Brian C. J. Moore. 
%     "Derivation of auditory filter shapes from notched-noise data"
%     Hearing Research, Vol. 47 pp. 103-138, 1990 
% 
% Fortran code at the back of this article implements this as:
%   c1 = 24.673; c2 = 4.368; c3 = 2302.6/(c1*c2);
%   freqERB = c3*log10(c2*freqHz/1000 + 1);
% 
% pph Feb. 3, 2004

function [freqVectorERB] = freq2erb(freqVectorHz)


%c1 = 24.673;
%c2 = 4.368;
%c3 = 2302.6/(c1*c2);
%freqVectorERB = c3*log10(c2*freqVectorHz/1000 + 1);

freqVectorERB = 21.4 * log10(0.00437*freqVectorHz + 1);