%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Institution: Stanford University
% Project: RealSimple Psychoacoustics Lab
% Author: Ryan J. Cassidy
% Date: Fall 2006
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% LOADLOUDNESSTESTSOUND Creates and returns an artificial test sound for the
% RealSimple Psychoacoustics Lab.
%
% x = loadLoudnessTestSound()
%
%    - x: the output signal (sampling rate is 32 kHz, as assumed in [1]). 
%
% [1] B. R. Glasberg and B. C. J. Moore, "A model of loudness applicable to
% time-varying sounds", Journal of the Audio Engineering Society,
% 50(5):331--342, 2002.
% 
% VERSION CONTROL INFORMATION:
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function x = loadLoudnessTestSound()

fs = 32e3; % As assumed in [1].

tb_freqs = [1e3,10e3];
tb_gains_db = [10.0,10.0];

x = [];
tb_dur = 200e-3; % seconds
t_one_burst = [0:(1/fs):(tb_dur - (1/fs))]';

pad_with_silence = 1; % place a burst of silence after each toneburst?

for i_=1:length(tb_freqs)
  x = [x; ...
       sin(2*pi*tb_freqs(i_)*t_one_burst)*10^(tb_gains_db(i_)/20);...
      ];  

  if pad_with_silence
    x = [x;...
	 zeros(length(t_one_burst),1)];
  end

end

x = x + rand([length(x),1])*10^(-80/20); % BUG_RJC: Don't know why we need
                                         % to add this noise to keep
                                         % portions of the excitogram from
                                         % going to negative infinity.

