% Reference:
%     Brian R. Glasberg and Brian C. J. Moore. 
%     "A Model of Loudness Applicable to Time-Varying Sounds" 
%     Journal of the Audio Engineering Society, Vol. 50, No. 5 (May), 2002
% 
% In order to have adequate spectral resolution at low frequencies and
% adequate temporal resolution at high frequencies, different FFTs are 
% calculated, using longer signal segments for low frequencies and shorter
% segments for higher frequencies. Recommended in the article (pp. 333-334, 
% section 1.2 "Calculation of Running Spectrum and Excitation Pattern"):
%
% freqRangesHz = [20,80,500,1250,2540,4050,15000]; % for 32KHz fs
% segDurationsMS = [64,32,16,8,4,2]; % corresponding to FFT ranges at 32KHz fs
% Frequencies falling between 20-80 Hz use 64 ms segments, while those
% falling between 4050-15000 Hz use 2 ms segments.
%
% If the relationship between the frequency range edges and the segment
% durations are preserved, these would be reasonable values when a sampling
% rate of 44.1 kHz is used:
% fftRangesHz = [0,80,500,1250,2540,4050,10000,22050]; % to cover audio range
% segDurationsMS = [64,32,16,8,4,2,1]; % corresponding to FFT ranges
% However, a segment duration of 1 ms would be too short when a 1 ms hop
% size between time frames is used (the authors use a 1 ms hop size).
% 
% In practice, it seems practical for the range above 4050 Hz to have
% a segment duration of 2 ms (as long as the hop size equal or below 1 ms,
% so that there is at least a 50% overlap between frames). The following
% values are to be used by the function cochlearInput2fftInt.m, so that
% frequencies below 80 Hz use 64 ms segments while frequencies above 4050 
% Hz use 2 ms segments.
%
% pph, Feb. 4, 2004

freqRangesHz = [0,80,500,1250,2540,4050]; % to cover audio range
segDurationsMS = [64,32,16,8,4,2]; % corresponding to FFT ranges
