% Graph values taken from:
%     Brian C. J. Moore, Brian R. Glasberg, and Thomas Baer. 
%     "A Model for the Prediction of Thresholds, Loudness, and Partial
%        Loudness" 
%     Journal of the Audio Engineering Society, Vol. 45, No. 4 (April), 1997
%
% Interpolation can be done with these array pairs to find intermediate 
% values for parameters (A,alpha,E_thrq) needed in the calculation of 
% specific loudness from the excitation pattern.
%  
% pph, Feb. 3, 2004

% Internal excitation level at threshold for monaural listening
% Assumed invariant above 500 Hz (e.g., E_thrq = 3.6 dB for f > 500 Hz)
% taken from Figures 4 and 8, pp. 226 and 229
E_thrqDB = [26.2, 20.2, 14.5, 6.3, 3.6]; % linear axis
E_thrqHz = [52, 74, 108, 253, 500]; % logarithmic axis


% Value of parameter alpha and A as a function of parameter G
% taken (eyeballed) from Figures 6 and 7, p. 228
GPointsDB = [-25, -20, -15, -10, -5, 0]; % linear axis
alphaPoints = [0.267, 0.25, 0.236, 0.222, 0.21, 0.2]; % linear axis
APoints = [8.8, 7.5, 6.6, 5.75, 5.15, 4.62]; % linear axis

